pub fn auth_context<B>(req: &Request<B>) -> AuthContextExpand description
Return the request authentication context, defaulting to anonymous when the auth layer has not run.
pub fn auth_context<B>(req: &Request<B>) -> AuthContextReturn the request authentication context, defaulting to anonymous when the auth layer has not run.